<?php
/**
 * Implementation of the Custom Background feature.
 * http://codex.wordpress.org/Custom_Backgrounds
 *
 * @package Ghostbird
 * @since 1.2
 */

/**
 * Setup the WordPress core custom background feature.
 *
 * Use add_theme_support to register support for WordPress 3.4+
 * as well as provide backward compatibility for previous versions.
 * Use feature detection of wp_get_theme() which was introduced
 * in WordPress 3.4.
 *
 * Hooks into the after_setup_theme action.
 *
 * @package Ghostbird
 * @since 1.2
 */
function ghostbird_custom_background_setup() {
	$args = array(
		'default-color' => '375876',
		'default-image' => get_template_directory_uri() . '/images/diagonal-stripes.png',
	);

	$args = apply_filters( 'ghostbird-custom-background-args', $args );

	if ( function_exists( 'wp_get_theme' ) ) {
		add_theme_support( 'custom-background', $args );
	} else {
		define( 'BACKGROUND_COLOR', $args['default-color'] );
		define( 'BACKGROUND_IMAGE', $args['default-image'] );
		add_custom_background();
	}
}

add_action( 'after_setup_theme', 'ghostbird_custom_background_setup' );

/**
 * Get Background color for use in CSS.
 *
 * @since 1.2
 */
function ghostbird_get_background_color() {
	$color = get_background_color();

	if ( empty( $color ) )
		$color = get_theme_support( 'custom-background', 'default-color' );

	if ( empty( $color ) )
		$color = 'transparent';
	else
		$color = '#' . $color;

	return $color;
}