<?php

/**
 * Support for the Portfolio Post Type Plugin.
 *
 * @see http://wordpress.org/extend/plugins/portfolio-post-type/
 * @see archive-portfolio.php
 * @see single-portfolio.php
 *
 * @package      Ghostbird
 * @author       Michael Fields <michael@mfields.org>
 * @copyright    Copyright (c) 2012, Michael Fields
 * @license      http://opensource.org/licenses/gpl-2.0.php GNU Public License
 * @since        1.2
 */
class Ghostbird_Portfolio_Post_Type {

	public static function setup() {
		add_action( 'init', array( __class__, 'init' ), 11 ); // After plugin registers custom objects.
	}

	/**
	 * Only hook in custom functionality if the post type exists.
	 *
	 * @since 1.2
	 */
	public static function init() {
		if ( ! post_type_exists( 'portfolio' ) )
			return;

		add_filter( 'ghostbird_post_label_plural', array( __class__, 'portfolio_label_plural' ), 10, 2 );
		add_action( 'template_redirect', array( __class__, 'template_redirect' ), 100 ); // Late in case plugins hook in at 10.
	}

	/**
	 * Swap out the plural portfolio label for use in sentences.
	 *
	 * @since 1.2
	 */
	public static function portfolio_label_plural( $label, $post_type ) {
		if ( is_admin() )
			return $label;

		if ( 'portfolio' == $post_type )
			return __( 'portfolio items', 'ghostbird' );

		return $label;
	}

	/**
	 * Recycle the portfolio archive for use with it's registered taxonomies too.
	 *
	 * @since 1.2
	 */
	public static function template_redirect() {
		$taxonomies = get_object_taxonomies( 'portfolio' );
		foreach ( (array) $taxonomies as $taxonomy ) {
			if ( is_tax( $taxonomy ) ) {
				$template = locate_template( 'archive-portfolio.php' );
				if ( $template ) {
					include $template;
					exit;
				}
			}
		}
	}
}

Ghostbird_Portfolio_Post_Type::setup();